/*------------------------------------------------------------------------------
*
*	Half-Life JailBreak Revision Log
*
*	$History: jailteams.cpp $
*       
*       *****************  Version 7  *****************
*       User: Tim Smith    Date: 4/27/99    Time: 10:08a
*       Updated in $/HLJB/cl_dll
*       Completed team based scoring system
*       
*       *****************  Version 6  *****************
*       User: Tim Smith    Date: 4/22/99    Time: 9:48p
*       Updated in $/HLJB/cl_dll
*       Initial version of voting system completed
*       
*       *****************  Version 5  *****************
*       User: Tim Smith    Date: 4/16/99    Time: 11:12p
*       Updated in $/HLJB/cl_dll
*       Modified to use new team icons
*       
*       *****************  Version 4  *****************
*       User: Tim Smith    Date: 4/16/99    Time: 1:26p
*       Updated in $/HLJB/cl_dll
*       Players team is always shown on top
*       
*       *****************  Version 3  *****************
*       User: Tim Smith    Date: 4/15/99    Time: 11:37p
*       Updated in $/HLJB/cl_dll
*       Team scores are now drawn at the same intensity as the health.
*       
*       *****************  Version 2  *****************
*       User: Tim Smith    Date: 4/15/99    Time: 9:55a
*       Updated in $/HLJB/cl_dll
*       Initial version of the HUD completed
*       
*       *****************  Version 1  *****************
*       User: Tim Smith    Date: 4/14/99    Time: 5:13p
*       Created in $/HLJB/cl_dll
*       
*-----------------------------------------------------------------------------*/

//
// flashlight.cpp
//
// implementation of CHudJailTeams class
//

#include "hud.h"
#include "util.h"
#include "parsemsg.h"

#include <string.h>
#include <stdio.h>

DECLARE_MESSAGE( m_JailTeams, JVoteStatus );

int CHudJailTeams::Init(void)
{

	HOOK_MESSAGE( JVoteStatus );

	m_iFlags |= HUD_ACTIVE;
	m_iFlags |= HUD_INTERMISSION;

	gHUD.AddHudElem(this);

	return 1;
};

void CHudJailTeams::Reset(void)
{
	m_nVoteStatus = 0;
}

#define SPRITE_BARS		0
#define SPRITE_NEG		1
#define SPRITE_VOTE		2
#define SPRITE_VOTEYES	3
#define SPRITE_VOTENO	4
#define SPRITE_TEAM0	5

static const char *s_pszSprits [7] =
{
	"jail_bars",
	"jail_negative",
	"jail_vote",
	"jail_voteyes",
	"jail_voteno",
	"jail_red_icon",
	"jail_blue_icon",
};

int CHudJailTeams::VidInit(void)
{
	for (int i = 0; i < 7; i++)
	{
		int n = gHUD.GetSpriteIndex( s_pszSprits [i] );
		m_hSprites [i] = gHUD .GetSprite (n);
		m_prcs [i] = &gHUD .GetSpriteRect (n);
	}

	m_iWidth = m_prcs [SPRITE_BARS] ->right - m_prcs [SPRITE_BARS] ->left;
	m_iHeight = m_prcs [SPRITE_BARS] ->bottom - m_prcs [SPRITE_BARS] ->top;

	return 1;
};

#define RGB_BARS 0x00808080
#define RGB_COUNT 0x00FFFFFF

int CHudJailTeams::Draw(float flTime)
{
	int r, g, b;
	wrect_t rc;

	if (ScreenWidth < 640)
	{
		if ( gHUD .m_Menu .m_iFlags & HUD_ACTIVE )
			return 1;
		if ( gHUD.m_Scoreboard.m_iShowscoresHeld )
			return 1;
	}

	// find starting position to draw from, along left-hand side of screen
	int x = 5;
	int y = ScreenHeight / 2;

	//
	// Create an array that contains the order of how the icons will be drawn.
	// The current players team will be last
	//

	int nCount = 0;
	int anIndexes [32];
	int nOwnteam = -1;
	for (int i = gHUD .m_Scoreboard .m_iNumTeams - 1; i > 0; i--)
	{
		if (!gHUD .m_Scoreboard .m_TeamInfo [i] .ownteam)
			anIndexes [nCount++] = i;
		else
			nOwnteam = i;
	}
	if (nOwnteam >= 0)
		anIndexes [nCount++] = nOwnteam;

	//
	// Loop through the teams backwards
	//

	for (i = 0; i < gHUD .m_Scoreboard .m_iNumTeams - 1; i++)
	{
		int nIndex = anIndexes [i];

		//
		// Adjust y
		//

		y -= m_iHeight + 5;

		//
		// Get the color
		//

		switch (nIndex)
		{
			case 1:
				r = 255; g = 0; b = 0;
				break;
			case 2:
				r = 0; g = 0; b = 255;
				break;
			default:
				r = 0; g = 0; b = 0; //ETS must be changed for more teams
				break;
		}

		//
		// Draw the base icon
		//

		SPR_Set( m_hSprites [SPRITE_TEAM0 + nIndex - 1], r, g, b);
		SPR_DrawAdditive( 0, x, y, m_prcs [SPRITE_TEAM0 + nIndex - 1] );

		//
		// Draw the jail part
		//

		if (gHUD .m_Scoreboard .m_TeamInfo [nIndex] .injail)
		{
			int injail = gHUD .m_Scoreboard .m_TeamInfo [nIndex] .injail;
			int players = gHUD .m_Scoreboard .m_TeamInfo [nIndex] .players;

			//
			// Draw the bars
			//

			int show = (int) (((float) m_iHeight / (float) players) * injail);

			UnpackRGB(r,g,b, RGB_BARS);
			SPR_Set ( m_hSprites [SPRITE_BARS], r, g, b);
			rc = *m_prcs [SPRITE_BARS];
			rc .top += m_iHeight - show;
			SPR_DrawAdditive( 0, x, y + m_iHeight - show, &rc );

			//
			// Draw the number of jailed
			//

			UnpackRGB(r,g,b, RGB_COUNT);
			gHUD.DrawHudNumberString( x + 20, y + 9, x, injail, r, g, b );
		}

		//
		// Draw the score
		//

		UnpackRGB(r,g,b, RGB_YELLOWISH);
		ScaleColors(r, g, b, MIN_ALPHA );
		int nScore = gHUD .m_Scoreboard .m_TeamInfo [nIndex] .executions;
		int nx = x + m_iWidth + 5;
		if (nScore < 0)
		{
			int ny = y + (m_iHeight - (m_prcs [SPRITE_NEG] ->bottom - 
				m_prcs [SPRITE_NEG] ->top)) / 2;
			SPR_Set(m_hSprites [SPRITE_NEG], r, g, b );
			SPR_DrawAdditive(0, nx, ny, m_prcs [SPRITE_NEG]);
			nx += m_prcs [SPRITE_NEG] ->right - m_prcs [SPRITE_NEG] ->left;
			nScore = -nScore;
		}
		gHUD.DrawHudNumber (nx, y + (m_iHeight - gHUD .m_iFontHeight) / 2, 
			DHN_DRAWZERO, nScore, r, g, b);
	}

	//
	// Draw the vote icon
	//

	if (m_nVoteStatus != 0)
	{
		int nIcon;
		if (m_nVoteStatus == 1)
			nIcon = SPRITE_VOTE;
		else if (m_nVoteStatus == 2)
			nIcon = SPRITE_VOTEYES;
		else
			nIcon = SPRITE_VOTENO;
		y -= m_iHeight + 5;
		UnpackRGB(r,g,b, RGB_YELLOWISH);
		SPR_Set( m_hSprites [nIcon], r, g, b);
		SPR_DrawAdditive( 0, x, y, m_prcs [nIcon] );
	}
	return 1;
}

// Message handler for JVoteStatus message
// accepts 1 value:
//		byte: 0 no vote, 1 vote pending, 2 done voted
//
int CHudJailTeams :: MsgFunc_JVoteStatus( const char *pszName, int iSize, void *pbuf )
{
	BEGIN_READ( pbuf, iSize );

	m_nVoteStatus = READ_BYTE ();
	return 1;
}